@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2023, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2023, 2025, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -39,8 +39,22 @@ constexpr inline std::array k_excluded_users = {
 };
 
 constexpr inline std::array k_mhs_excluded_users = {
-    "administrator", "ociadmin",           "ocidbm",   "ocimonitor",
-    "ocirpl",        "oracle-cloud-agent", "rrhhuser",
+    "administrator",
+    "mysql_option_tracker_persister",
+    "mysql_rest_service_admin",
+    "mysql_rest_service_data_provider",
+    "mysql_rest_service_dev",
+    "mysql_rest_service_meta_provider",
+    "mysql_rest_service_schema_admin",
+    "mysql_rest_service_user",
+    "mysql_task_admin",
+    "mysql_task_user",
+    "ociadmin",
+    "ocidbm",
+    "ocimonitor",
+    "ocirpl",
+    "oracle-cloud-agent",
+    "rrhhuser",
 };
 
 constexpr inline std::array k_excluded_schemas = {
@@ -56,6 +70,10 @@ constexpr inline std::array k_mhs_excluded_schemas = {
     "mysql_firewall",
     // stores the options information
     "mysql_option",
+    // stores the MRS metadata
+    "mysql_rest_service_metadata",
+    // MRS related
+    "mysql_tasks",
 };
 
 }  // namespace common
