@@ -52,9 +52,16 @@ FUNCTIONS
       removeCluster(clusterName[, options])
             Removes a Replica cluster from a ClusterSet.
 
+      routerOptions(options)
+            Lists the configuration options of the ClusterSet's Routers.
+
       routingOptions([router])
             Lists the ClusterSet Routers configuration options.
 
+            ATTENTION: This function is deprecated and will be removed in a
+                       future release of MySQL Shell. Use
+                       ClusterSet.routerOptions() instead.
+
       setOption(option, value)
             Changes the value of an option for the whole ClusterSet.
 
@@ -136,6 +143,11 @@ DESCRIPTION
       - The target instance must have the same credentials used to manage the
         ClusterSet.
 
+      The Replica Cluster's name must be non-empty and no greater than 63
+      characters long. It can only start with an alphanumeric character or with
+      _ (underscore), and can only contain alphanumeric, _ ( underscore), .
+      (period), or - ( hyphen) characters.
+
       For the detailed list of requirements to create an InnoDB Cluster, please
       use \? createCluster
 
@@ -143,10 +155,6 @@ DESCRIPTION
 
       The options dictionary can contain the following values:
 
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - dryRun: boolean if true, all validations and steps for creating a
         Replica Cluster are executed, but no changes are actually made. An
         exception will be thrown when finished.
@@ -162,7 +170,7 @@ DESCRIPTION
       - memberSslMode: SSL mode for communication channels opened by Group
         Replication from one server to another.
       - certSubject: instance's certificate subject to use when
-        'memberAuthType' contains "CERT_SUBJECT".
+        'memberAuthType' contains "CERT_SUBJECT" or "CERT_SUBJECT_PASSWORD".
       - ipAllowlist: The list of hosts allowed to connect to the instance for
         group replication. Only valid if communicationStack=XCOM.
       - localAddress: string value with the Group Replication local address to
@@ -185,12 +193,33 @@ DESCRIPTION
         'mysql_innodb_cluster_###'@'hostname'). Default is %. It must be
         possible for any member of the Cluster to connect to any other member
         using accounts with this hostname value.
-      - communicationStack: The Group Replication protocol stack to be used in
-        the Cluster: XCom (legacy) or MySQL.
+      - communicationStack: The Group Replication communication stack to be
+        used in the Cluster: XCom (legacy) or MySQL.
       - transactionSizeLimit: integer value to configure the maximum
         transaction size in bytes which the Cluster accepts
       - paxosSingleLeader: boolean value used to enable/disable the Group
         Communication engine to operate with a single consensus leader.
+      - clusterSetReplicationConnectRetry: integer that specifies the interval
+        in seconds between the reconnection attempts that the replica makes
+        after the connection to the source times out.
+      - clusterSetReplicationRetryCount: integer that sets the maximum number
+        of reconnection attempts that the replica makes after the connection to
+        the source times out.
+      - clusterSetReplicationHeartbeatPeriod: decimal that controls the
+        heartbeat interval, which stops the connection timeout occurring in the
+        absence of data if the connection is still good.
+      - clusterSetReplicationCompressionAlgorithms: string that specifies the
+        permitted compression algorithms for connections to the replication
+        source.
+      - clusterSetReplicationZstdCompressionLevel: integer that specifies the
+        compression level to use for connections to the replication source
+        server that use the zstd compression algorithm.
+      - clusterSetReplicationBind: string that determines which of the
+        replica's network interfaces is chosen for connecting to the source.
+      - clusterSetReplicationNetworkNamespace: string that specifies the
+        network namespace to use for TCP/IP connections to the replication
+        source server or, if the MySQL communication stack is in use, for Group
+        Replication’s group communication connections.
 
       The recoveryMethod option supports the following values:
 
@@ -283,7 +312,8 @@ DESCRIPTION
         it leaves the cluster unintentionally or exhausts its auto-rejoin
         attempts. Requires MySQL 8.0.18 or newer.
 
-      If exitStateAction is not specified READ_ONLY will be used by default.
+      If exitStateAction is not specified, it defaults to OFFLINE_MODE for
+      server versions 8.4.0 or newer, and READ_ONLY otherwise.
 
       The consistency option supports the following values:
 
@@ -293,7 +323,9 @@ DESCRIPTION
       - EVENTUAL: if used, read queries to the new primary are allowed even if
         the backlog isn't applied.
 
-      If consistency is not specified, EVENTUAL will be used by default.
+      If consistency is not specified, it defaults to
+      BEFORE_ON_PRIMARY_FAILOVER for server versions 8.4.0 or newer, and
+      EVENTUAL otherwise.
 
       The value for exitStateAction is used to configure how Group Replication
       behaves when a server instance leaves the group unintentionally (for
@@ -307,7 +339,8 @@ DESCRIPTION
       option accepts case-insensitive string values, being the accepted values:
       OFFLINE_MODE (or 2), ABORT_SERVER (or 1) and READ_ONLY (or 0).
 
-      The default value is READ_ONLY.
+      The default value is OFFLINE_MODE for server versions 8.4.0 or newer, and
+      READ_ONLY otherwise.
 
       The value for memberWeight is used to set the Group Replication system
       variable 'group_replication_member_weight'. The memberWeight option
@@ -323,10 +356,20 @@ DESCRIPTION
       When set to BEFORE_ON_PRIMARY_FAILOVER, whenever a primary failover
       happens in single-primary mode (default), new queries (read or write) to
       the newly elected primary that is applying backlog from the old primary,
-      will be hold before execution until the backlog is applied. When set to
-      EVENTUAL, read queries to the new primary are allowed even if the backlog
-      isn't applied but writes will fail (if the backlog isn't applied) due to
-      super-read-only mode being enabled. The client may return old values.
+      will be hold before execution until the backlog is applied. Special care
+      is needed if LOCK / UNLOCK queries are used in a secondary, because the
+      UNLOCK statement can be held. This means that, if the secondary is
+      promoted, and transactions from the primary are being applied that target
+      locked tables, they won't be applied and an explicit UNLOCK will also
+      hold because the secondary needs to finish applying the transactions from
+      the previous primary. See
+      https://dev.mysql.com/doc/refman/en/group-replication-system-variables.html#sysvar_group_replication_consistency
+      for more details.
+
+      When set to EVENTUAL, read queries to the new primary are allowed even if
+      the backlog isn't applied but writes will fail (if the backlog isn't
+      applied) due to super-read-only mode being enabled. The client may return
+      old values.
 
       When set to BEFORE, each transaction (RW or RO) waits until all preceding
       transactions are complete before starting its execution. This ensures
@@ -357,7 +400,8 @@ DESCRIPTION
       accepted values: EVENTUAL (or 0), BEFORE_ON_PRIMARY_FAILOVER (or 1),
       BEFORE (or 2), AFTER (or 3), and BEFORE_AND_AFTER (or 4).
 
-      The default value is EVENTUAL.
+      It defaults to BEFORE_ON_PRIMARY_FAILOVER for server versions 8.4.0 or
+      newer, and EVENTUAL otherwise.
 
       The value for expelTimeout is used to set the Group Replication system
       variable 'group_replication_member_expel_timeout' and configure how long
@@ -414,8 +458,6 @@ DESCRIPTION
       The option is available on MySQL 8.0.31 or newer and the default value is
       'OFF'.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
 //@<OUT> RemoveCluster
 NAME
       removeCluster - Removes a Replica cluster from a ClusterSet.
@@ -755,7 +797,19 @@ RETURNS
 
 DESCRIPTION
       This function lists and provides information about all Router instances
-      registered on the Clusters members of the ClusteSet.
+      registered on the Clusters members of the ClusterSet.
+
+      For each router, the following information is provided, when available:
+
+      - hostname: Hostname.
+      - lastCheckIn: Timestamp of the last statistics update (check-in).
+      - roPort: Read-only port (Classic protocol).
+      - roXPort: Read-only port (X protocol).
+      - rwPort: Read-write port (Classic protocol).
+      - rwSplitPort: Read-write split port (Classic protocol).
+      - rwXPort: Read-write port (X protocol).
+      - targetCluster: Target Cluster for Router routing operations.
+      - version: Version.
 
 //@<OUT> routingOptions
 NAME
@@ -773,9 +827,47 @@ RETURNS
       Router.
 
 DESCRIPTION
+      ATTENTION: This function is deprecated and will be removed in a future
+                 release of MySQL Shell. Use ClusterSet.routerOptions()
+                 instead.
+
       This function lists the Router configuration options of all Routers of
       the ClusterSet or the target Router.
 
+//@<OUT> routerOptions
+NAME
+      routerOptions - Lists the configuration options of the ClusterSet's
+                      Routers.
+
+SYNTAX
+      <ClusterSet>.routerOptions(options)
+
+WHERE
+      options: Dictionary with options for the operation.
+
+RETURNS
+      A JSON object with the list of Router configuration options.
+
+DESCRIPTION
+      This function lists the Router configuration options of the ClusterSet
+      (global), and the Router instances. By default, only the options that can
+      be changed from Shell (dynamic options) are displayed. Router instances
+      with different configurations than the global ones will include the
+      differences under their dedicated description.
+
+      The options dictionary may contain the following attributes:
+
+      - extended: Verbosity level of the command output.
+      - router: Identifier of the Router instance to be displayed.
+
+      The extended option supports Integer or Boolean values:
+
+      - 0: Includes only options that can be changed from Shell (default);
+      - 1: Includes all ClusterSet global options and, per Router, only the
+        options that have a different value than the corresponding global one.
+      - 2: Includes all Cluster and Router options.
+      - Boolean: equivalent to assign either 0 (false) or 1 (true).
+
 //@<OUT> setRoutingOption
 NAME
       setRoutingOption - Changes the value of either a global Routing option or
@@ -800,10 +892,14 @@ DESCRIPTION
         value is 'primary'.
       - invalidated_cluster_policy: Routing policy to be taken when the target
         cluster is detected as being invalidated. Default value is 'drop_all'.
-      - stats_updates_frequency: Frequency of Router check-in updates. Default
-        value is 0.
+      - stats_updates_frequency: Number of seconds between updates that the
+        Router is to make to its statistics in the InnoDB Cluster metadata.
       - use_replica_primary_as_rw: Enable/Disable the RW Port in Replica
         Clusters. Disabled by default.
+      - tags: Associates an arbitrary JSON object with custom key/value pairs
+        with the ClusterSet metadata.
+      - read_only_targets: Routing policy to define Router's usage of Read
+        Replicas. Default is 'append'.
 
       The target_cluster option supports the following values:
 
@@ -820,9 +916,10 @@ DESCRIPTION
         connections will be accepted (default).
 
       The stats_updates_frequency option accepts positive integers and sets the
-      frequency of Router check-in updates in seconds in the Metadata. If set
-      to 0 (default), no periodic updates are done. Router will round up the
-      value to be a multiple of Router's TTL, i.e.:
+      frequency of updates of Router stats (timestamp, version, etc.), in
+      seconds, in the Metadata. If set to 0 (default), no periodic updates are
+      done. Router will round up the value to be a multiple of Router's TTL,
+      i.e.:
 
       - If lower than TTL its gets rounded up to TTL, e.g. TTL=30, and
         stats_updates_frequency=1, effective frequency is 30 seconds.
@@ -844,6 +941,15 @@ DESCRIPTION
       default, the option is false and Router blocks connections to the RW port
       in this scenario.
 
+      The read_only_targets option supports the following values:
+
+      - all: All Read Replicas of the target Cluster should be used along the
+        other SECONDARY Cluster members for R/O traffic.
+      - read_replicas: Only Read Replicas of the target Cluster should be used
+        for R/O traffic.
+      - secondaries: Only Secondary members of the target Cluster should be
+        used for R/O traffic (default).
+
 //@<OUT> setOption
 NAME
       setOption - Changes the value of an option for the whole ClusterSet.
@@ -918,10 +1024,6 @@ DESCRIPTION
       - requireCertSubject: Optional SSL certificate subject for the account.
       - dryRun: boolean value used to enable a dry run of the account setup
         process. Default value is False.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -935,16 +1037,11 @@ DESCRIPTION
       permissions to be granted to `user` account without actually creating
       and/or performing any changes to it.
 
-      The interactive option can be used to explicitly enable or disable the
-      interactive prompts that help the user through the account setup process.
-
       To change authentication options for an existing account, set `update` to
       `true`. It is possible to change password without affecting certificate
       options or vice-versa but certificate options can only be changed
       together.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
 //@<OUT> setupRouterAccount
 NAME
       setupRouterAccount - Create or upgrade a MySQL account to use with MySQL
@@ -983,10 +1080,6 @@ DESCRIPTION
       - requireCertSubject: Optional SSL certificate subject for the account.
       - dryRun: boolean value used to enable a dry run of the account setup
         process. Default value is False.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -1000,12 +1093,7 @@ DESCRIPTION
       permissions to be granted to `user` account without actually creating
       and/or performing any changes to it.
 
-      The interactive option can be used to explicitly enable or disable the
-      interactive prompts that help the user through the account setup process.
-
       To change authentication options for an existing account, set `update` to
       `true`. It is possible to change password without affecting certificate
       options or vice-versa but certificate options can only be changed
       together.
-
-      ATTENTION: The interactive option will be removed in a future release.
